@@ -4,9 +4,19 @@ package Catmandu::MARC;
 
 Catmandu::MARC - Catmandu modules for working with MARC data
 
+=begin markdown
+
+# STATUS
+
+[![Build Status](https://travis-ci.org/LibreCat/Catmandu-MARC.svg?branch=master)](https://travis-ci.org/LibreCat/Catmandu-MARC)
+[![Coverage](https://coveralls.io/repos/LibreCat/Catmandu-MARC/badge.png?branch=master)](https://coveralls.io/r/LibreCat/Catmandu-MARC)
+[![CPANTS kwalitee](http://cpants.cpanauthors.org/dist/Catmandu-MARC.png)](http://cpants.cpanauthors.org/dist/Catmandu-MARC)
+
+=end markdown
+
 =cut
 
-our $VERSION = '0.210';
+our $VERSION = '0.211';
 
 =head1 SYNOPSIS
 
@@ -18,7 +28,7 @@ our $VERSION = '0.210';
 
  $ catmandu convert MARC --fix "marc_map(245,title)" < data.mrc
 
- $ catmandu covert MARC --fix myfixes.txt < data.mrc
+ $ catmandu convert MARC --fix myfixes.txt < data.mrc
 
  myfixes:
  
